@@ -21,13 +21,17 @@
 .col_picker <- function(level, palette, alpha = NULL) {
   col <- palette[floor(level * (length(palette) - 1)) + 1]
   if (!is.null(alpha)) {
-    col <- apply(sapply(col, grDevices::col2rgb) / 255, 2,
-      function(x)
-        grDevices::rgb(x[1], x[2], x[3], alpha = alpha))
+    col <- apply(
+      sapply(col, grDevices::col2rgb) / 255, 2,
+      function(x) {
+        grDevices::rgb(x[1], x[2], x[3], alpha = alpha)
+      }
+    )
   }
   col
 }
 
 ### default are gray - > red
-default_colors <- function(n , alpha = 1)
+default_colors <- function(n, alpha = 1) {
   grDevices::colorRampPalette(c("#EE0000", "#EE9999", "#EEEEEE"), alpha = alpha)(n)
+}
