@@ -16,26 +16,23 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-scatterplot_ggplot2 <- function(
-    x,
-    measure = c("support", "confidence"),
-    shading = "lift",
-    control = NULL,
-    ...) {
+scatterplot_ggplot2 <- function(x,
+                                measure = c("support", "confidence"),
+                                shading = "lift",
+                                control = NULL,
+                                ...) {
   control <- c(control, list(...))
-  control <- .get_parameters(
-    control,
-    list(
-      main = paste("Scatter plot for", length(x), class(x)),
-      colors = default_colors(2),
-      jitter = NA,
-      engine = "ggplot2"
-    )
-  )
-
+  control <- .get_parameters(control,
+                             list(
+                               main = paste("Scatter plot for", length(x), class(x)),
+                               colors = default_colors(2),
+                               jitter = NA,
+                               engine = "ggplot2"
+                             ))
+  
   colors <- rev(control$colors)
   jitter <- control$jitter
-
+  
   q <- quality(x)
   q[["order"]] <- as.factor(size(x))
   qnames <- names(q)
@@ -46,7 +43,7 @@ scatterplot_ggplot2 <- function(
     o <- order(q[[shading]], decreasing = FALSE)
     q <- q[o, , drop = FALSE]
   }
-
+  
   # for(i in 1:ncol(q)) {
   #   infin <- is.infinite(q[[i]])
   #   if(any(infin)) {
@@ -55,14 +52,14 @@ scatterplot_ggplot2 <- function(
   #     q[[i]][infin] <- replinfin
   #   }
   # }
-
+  
   ### add x/y-jitter
   jitter <- jitter[1]
   if (is.na(jitter) && any(duplicated(q[, measure]))) {
     message("To reduce overplotting, jitter is added! Use jitter = 0 to prevent jitter.")
     jitter <- .jitter_default
   }
-
+  
   if (!is.na(jitter) && jitter > 0) {
     for (m in measure) {
       if (is.numeric(q[[m]])) {
@@ -70,7 +67,7 @@ scatterplot_ggplot2 <- function(
       }
     }
   }
-
+  
   if (!is.null(shading)) {
     p <-
       ggplot(q, aes(.data[[measure[1]]], y = .data[[measure[2]]], color = .data[[shading]])) +
@@ -83,7 +80,6 @@ scatterplot_ggplot2 <- function(
     }
     
   } else {
-  
     p <-
       ggplot(q, aes(.data[[measure[1]]], y = .data[[measure[2]]])) +
       geom_point()
@@ -92,12 +88,11 @@ scatterplot_ggplot2 <- function(
   p + ggtitle(control$main) + theme_linedraw()
 }
 
-matrix_ggplot2 <- function(
-    x,
-    measure = c("lift"),
-    shading = NA,
-    control = NULL,
-    ...) {
+matrix_ggplot2 <- function(x,
+                           measure = c("lift"),
+                           shading = NA,
+                           control = NULL,
+                           ...) {
   control <- c(control, list(...))
   control <- .get_parameters(
     control,
@@ -109,55 +104,49 @@ matrix_ggplot2 <- function(
       engine = "ggplot2"
     )
   )
-
+  
   colors <- rev(control$colors)
-
+  
   m <- rules2matrix(x, measure, control$reorder)
-
+  
   # reverse rows so highest value is in the top-left hand corner
   m <- m[nrow(m):1, ]
-
+  
   ## print labels
   writeLines("Itemsets in Antecedent (LHS)")
   print(colnames(m))
   writeLines("Itemsets in Consequent (RHS)")
   print(rownames(m))
-
+  
   dimnames(m) <- list(seq_len(nrow(m)), seq_len(ncol(m)))
-
+  
   # NOTE: nullify variables used for non-standard evaluation for tidyverse/ggplot2 below
   RHS <- LHS <- NULL
-
+  
   d <-
     m %>%
     as_tibble() %>%
     dplyr::mutate(RHS = seq_len(nrow(m))) %>%
-    pivot_longer(
-      cols = -c(RHS),
-      names_to = "LHS",
-      values_to = measure
-    )
+    pivot_longer(cols = -c(RHS),
+                 names_to = "LHS",
+                 values_to = measure)
   d$LHS <- as.integer(d$LHS)
-
+  
   ggplot(d, aes(x = LHS, y = RHS, fill = .data[[measure]])) +
     geom_raster() +
-    scale_fill_gradient(
-      low = colors[1],
-      high = colors[2],
-      na.value = 0
-    ) +
+    scale_fill_gradient(low = colors[1],
+                        high = colors[2],
+                        na.value = "#FFFFFFFF") +
     ggtitle(control$main) +
     scale_x_continuous(expand = c(0, 0)) +
-    scale_y_continuous(expand = c(0, 0)) +
-    theme_bw()
+    scale_y_continuous(expand = c(0, 0))
 }
 
-grouped_matrix_ggplot2 <- function(
-    x,
-    measure = c("support"),
-    shading = "lift",
-    control = NULL,
-    ...) {
+grouped_matrix_ggplot2 <- function(x,
+                                   measure = c("support"),
+                                   shading = "lift",
+                                   control = NULL,
+                                   ...) {
   control <- c(control, list(...))
   control <- .get_parameters(
     control,
@@ -172,7 +161,7 @@ grouped_matrix_ggplot2 <- function(
       engine = "ggplot2"
     )
   )
-
+  
   # get the clustering
   if (is.null(control$groups)) {
     gm <-
@@ -188,18 +177,18 @@ grouped_matrix_ggplot2 <- function(
     gm <- control$groups
   }
   control$groupes <- NULL ### for interactive plot
-
-
+  
+  
   m <- gm$m
   m2 <- gm$m2
-
+  
   not_shown_rhs <- 0
   if (nrow(m) > control$rhs_max) {
     not_shown_rhs <- nrow(m) - control$rhs_max
     m <- m[seq_len(control$rhs_max), , drop = FALSE]
     m2 <- m2[seq_len(control$rhs_max), , drop = FALSE]
   }
-
+  
   # convert to data.frame
   df <- data.frame(
     LHS = rep(ordered(colnames(m), levels = colnames(m)), times = nrow(m)),
@@ -209,10 +198,10 @@ grouped_matrix_ggplot2 <- function(
     measure = as.vector(t(m)),
     support = as.vector(t(m2))
   )
-
+  
   # NULLify for CRAN
   LHS <- RHS <- NULL
-
+  
   p <-
     ggplot(df, aes(
       x = LHS,
@@ -224,27 +213,22 @@ grouped_matrix_ggplot2 <- function(
     scale_color_gradient(low = control$col[2], high = control$col[1]) +
     labs(color = shading) +
     xlab("Items in LHS Groups") +
-    ylab(paste(
-      "RHS",
-      if (not_shown_rhs > 0) {
-        paste("(+", not_shown_rhs, " not shown)", sep = "")
-      } else {
-        ""
-      }
-    )) +
+    ylab(paste("RHS", if (not_shown_rhs > 0) {
+      paste("(+", not_shown_rhs, " not shown)", sep = "")
+    } else {
+      ""
+    })) +
     theme_linedraw() +
     scale_x_discrete(position = "top") +
     scale_y_discrete(position = "right") +
-    theme(
-      axis.text.x = element_text(
-        angle = 90,
-        hjust = 0,
-        vjust = .5
-      ),
-      legend.position = "bottom"
-    ) +
+    theme(axis.text.x = element_text(
+      angle = 90,
+      hjust = 0,
+      vjust = .5
+    ),
+    legend.position = "bottom") +
     scale_size(range = c(2, 8))
-
+  
   if (control$engine == "htmlwidget") {
     p <- plotly::ggplotly(p)
   }
