@@ -19,11 +19,12 @@
 # plotly interactive plots using d3.js
 
 ## Interface used by plot
-scatterplot_plotly <- function(x,
-  measure = measure,
-  shading = shading,
-  control = control,
-  ...) {
+scatterplot_plotly <- function(
+    x,
+    measure = measure,
+    shading = shading,
+    control = control,
+    ...) {
   control <- c(control, list(...))
   control <- .get_parameters(
     control,
@@ -38,12 +39,12 @@ scatterplot_plotly <- function(x,
       marker = list()
     )
   )
-  
+
   quality(x)[["order"]] <- size(x)
   qnames <- names(quality(x))
   measure <- qnames[pmatch(measure, qnames, duplicates.ok = TRUE)]
   if (!is.null(shading)) shading <- qnames[pmatch(shading, qnames)]
- 
+
   .plotly_scatter(
     x,
     measure,
@@ -56,23 +57,24 @@ scatterplot_plotly <- function(x,
   )
 }
 
-.plotly_scatter <- function(x,
-  measure = c("support", "confidence"),
-  shading = "lift",
-  colors = default_colors(2),
-  jitter = NA,
-  precision = 3,
-  max = 1000,
-  marker = list(),
-  ...) {
+.plotly_scatter <- function(
+    x,
+    measure = c("support", "confidence"),
+    shading = "lift",
+    colors = default_colors(2),
+    jitter = NA,
+    precision = 3,
+    max = 1000,
+    marker = list(),
+    ...) {
   colors <- rev(colors)
-  
+
   quality(x)$id <- seq_along(x)
   x <- limit(x, max, shading, measure)
-  
+
   ### reduce overplotting
   x <- rev(x)
-  
+
   q <- quality(x)[, c(measure, shading)]
   for (i in 1:ncol(q)) {
     infin <- is.infinite(q[[i]])
@@ -89,89 +91,100 @@ scatterplot_plotly <- function(x,
       q[[i]][infin] <- replinfin
     }
   }
-  
-  if (is(x, "rules"))
+
+  if (is(x, "rules")) {
     l <- labels(
       x,
-      itemSep = ',<BR>&nbsp;&nbsp;',
-      ruleSep = '<BR>&nbsp;&nbsp; => ',
-      setStart = '<B>{',
-      setEnd = '}</B>'
+      itemSep = ",<BR>&nbsp;&nbsp;",
+      ruleSep = "<BR>&nbsp;&nbsp; => ",
+      setStart = "<B>{",
+      setEnd = "}</B>"
     )
-  else
+  } else {
     l <- labels(x,
-      itemSep = ',<BR>&nbsp;&nbsp;',
-      setStart = '<B>{',
-      setEnd = '}</B>')
-  
+      itemSep = ",<BR>&nbsp;&nbsp;",
+      setStart = "<B>{",
+      setEnd = "}</B>"
+    )
+  }
+
   txt <- paste(
-    paste0('[', quality(x)$id, ']<BR>'),
+    paste0("[", quality(x)$id, "]<BR>"),
     l,
-    paste('<BR><BR>', measure[1], ": ", signif(q[, measure[1]], precision), sep = ""),
-    paste('<BR>', measure[2], ": ", signif(q[, measure[2]], precision), sep =
-        ""),
+    paste("<BR><BR>", measure[1], ": ", signif(q[, measure[1]], precision), sep = ""),
+    paste("<BR>", measure[2], ": ", signif(q[, measure[2]], precision),
+      sep =
+        ""
+    ),
     if (!is.null(shading)) {
-      paste('<BR>', shading, ": ",
-        if (is.numeric(q[, shading]))
+      paste("<BR>", shading, ": ",
+        if (is.numeric(q[, shading])) {
           signif(q[, shading], precision)
-        else
-          q[, shading], sep = "")
-    } else
+        } else {
+          q[, shading]
+        },
+        sep = ""
+      )
+    } else {
       ""
+    }
   )
-  
+
   ### add x/y-jitter
   jitter <- jitter[1]
   if (is.na(jitter) && any(duplicated(q[, measure]))) {
     message("To reduce overplotting, jitter is added! Use jitter = 0 to prevent jitter.")
     jitter <- .jitter_default
   }
-  
-  if (!is.na(jitter) && jitter > 0)
-    for (m in measure)
+
+  if (!is.na(jitter) && jitter > 0) {
+    for (m in measure) {
       q[[m]] <- jitter(q[[m]], factor = jitter, amount = 0)
-  
-  if (is.null(shading))
+    }
+  }
+
+  if (is.null(shading)) {
     p <-
-    plotly::plot_ly(
-      q,
-      type = "scatter",
-      x = q[, measure[1]],
-      y = q[, measure[2]],
-      hoverinfo = 'text',
-      text = txt,
-      mode = 'markers',
-      marker = marker
-    )
-  else if (shading == "order")
+      plotly::plot_ly(
+        q,
+        type = "scatter",
+        x = q[, measure[1]],
+        y = q[, measure[2]],
+        hoverinfo = "text",
+        text = txt,
+        mode = "markers",
+        marker = marker
+      )
+  } else if (shading == "order") {
     p <-
-    plotly::plot_ly(
-      q,
-      type = "scatter",
-      x = q[, measure[1]],
-      y = q[, measure[2]],
-      hoverinfo = 'text',
-      text = txt,
-      color = as.ordered(q[, shading]),
-      mode = 'markers',
-      marker = marker
-    )
-  else
+      plotly::plot_ly(
+        q,
+        type = "scatter",
+        x = q[, measure[1]],
+        y = q[, measure[2]],
+        hoverinfo = "text",
+        text = txt,
+        color = as.ordered(q[, shading]),
+        mode = "markers",
+        marker = marker
+      )
+  } else {
     p <-
-    plotly::plot_ly(
-      q,
-      type = "scatter",
-      x = q[, measure[1]],
-      y = q[, measure[2]],
-      hoverinfo = 'text',
-      text = txt,
-      color = q[, shading],
-      colors = colors,
-      mode = 'markers',
-      marker = marker
-    )  %>% plotly::colorbar(title = shading)
-  
-  
+      plotly::plot_ly(
+        q,
+        type = "scatter",
+        x = q[, measure[1]],
+        y = q[, measure[2]],
+        hoverinfo = "text",
+        text = txt,
+        color = q[, shading],
+        colors = colors,
+        mode = "markers",
+        marker = marker
+      ) %>% plotly::colorbar(title = shading)
+  }
+
+
   p %>%
     plotly::layout(
       hovermode = "closest",
@@ -193,10 +206,10 @@ matrix_plotly <- function(x, measure, shading, control, ...) {
       precision = 3
     )
   )
-  
+
   qnames <- names(quality(x))
   measure <- qnames[pmatch(measure, qnames, duplicates.ok = TRUE)]
-  
+
   .plotly_matrix(
     x,
     measure[1],
@@ -207,45 +220,46 @@ matrix_plotly <- function(x, measure, shading, control, ...) {
   )
 }
 
-.plotly_matrix <- function(x,
-  measure = "lift",
-  reorder = "none",
-  colors = default_colors(2),
-  precision = 3,
-  max = 1000) {
+.plotly_matrix <- function(
+    x,
+    measure = "lift",
+    reorder = "none",
+    colors = default_colors(2),
+    precision = 3,
+    max = 1000) {
   colors <- rev(colors)
- 
+
   x <- limit(x, max, measure = measure)
-  
+
   m <- rules2matrix(x, measure, reorder)
   m <- m[nrow(m):1, , drop = FALSE] # reverse rows
   m_s <-
     rules2matrix(x, measure = "support", reorder = "none")[rownames(m), colnames(m)]
   m_c <-
     rules2matrix(x, measure = "confidence", reorder = "none")[rownames(m), colnames(m)]
-  
+
   txt <-
-    t(outer(colnames(m), rownames(m), paste, sep = '<BR>&nbsp;&nbsp; => '))
+    t(outer(colnames(m), rownames(m), paste, sep = "<BR>&nbsp;&nbsp; => "))
   txt[] <- paste(
-    '<B>',
+    "<B>",
     txt,
-    '</B>',
-    '<BR>',
+    "</B>",
+    "<BR>",
     measure,
-    ': ',
+    ": ",
     signif(m, precision),
-    '<BR>',
-    'support',
-    ': ',
+    "<BR>",
+    "support",
+    ": ",
     signif(m_s, precision),
-    '<BR>',
-    'confidence',
-    ': ',
+    "<BR>",
+    "confidence",
+    ": ",
     signif(m_c, precision),
-    sep = ''
+    sep = ""
   )
   txt[is.na(m)] <- NA
-  
+
   plotly::plot_ly(
     z = m,
     x = colnames(m),
@@ -253,7 +267,7 @@ matrix_plotly <- function(x, measure, shading, control, ...) {
     type = "heatmap",
     colors = colors,
     colorbar = list(title = measure),
-    hoverinfo = 'text',
+    hoverinfo = "text",
     text = txt
   ) %>%
     plotly::layout(
